import logging
from rdflib import Graph

from cubicweb.appobject import AppObject
from cubicweb import Binary

from cubicweb_rodolf.process_helpers import get_graph_from_url
from cubicweb_rodolf.schema import ImportProcess


class DefaultProcessType(AppObject):
    __registry__ = "rodolf.appobject.processtype"
    __regid__ = "default"

    def __call__(self, import_process: ImportProcess, log: logging.Logger) -> Graph:
        import_recipe = import_process.import_recipe[0]
        dataservice = import_recipe.dataservice[0]
        graph = get_graph_from_url(dataservice.data_url, log)
        import_process.cw_set(
            has_output_dataset=self._cw.create_entity(
                "File",
                title=f"Graph file for ImportProcess#{import_process.eid}",
                data=Binary(graph.serialize(format="ttl").encode("utf8")),
                data_name=f"data_ImportProcess_{import_process.eid}.ttl",
                data_format="text/turtle",
            )
        )
        return graph
